@@ -1,6 +1,5 @@
 from datetime import datetime, timedelta
 from threading import Thread, Event
-import re
 
 try:
     # Python 2.6+
@@ -10,7 +9,6 @@ except ImportError:
 
 import socket
 import sys
-import time
 import traceback
 import urllib
 import urllib2
@@ -29,6 +27,7 @@ class Clip2ZeusApp(object):
         """Creates the container for common functionality"""
 
         logger.debug('Welcome to %s v%s' % (APP_TITLE, __version__))
+        logger.debug('** Using class %s **' % (self.__class__.__name__,))
 
         try:
             self.port = int(port)
@@ -94,7 +93,7 @@ class Clip2ZeusApp(object):
             return osx.Clip2ZeusOSX
         elif platform in ('linux', 'linux2'):
             import linux
-            return linux.Clip2ZeusLinux
+            return linux.determine_wm()
         else:
             raise UnsupportedPlatformError('%s is not currently supported!' % platform)
 
