@@ -3,17 +3,19 @@
 
 """
 Monitors the Windows system clipboard for text that contains URLs for conversion
-using 2ze.us"""
+using 2ze.us
+"""
 
 import time
 import win32clipboard as w
-from common import Clip2ZeusApp
+from clip2zeus.common import Clip2ZeusApp
 
 class Clip2ZeusWin32(Clip2ZeusApp):
 
     def do_clipboard_operation(self, func, *args, **kwargs):
         """Performs a quick clipboard operation, wrapping it with safety nets"""
 
+        result = ''
         try:
             w.OpenClipboard()
         except Exception, err:
@@ -33,23 +35,13 @@ class Clip2ZeusWin32(Clip2ZeusApp):
 
         return result
 
-    def monitor_clipboard(self):
-        """Regularly checks the system clipboard for data"""
+    def check_clipboard(self):
+        """Checks the system clipboard for data"""
 
         def get_data():
             return w.GetClipboardData(w.CF_TEXT)
 
-        try:
-            while True:
-                # only bother processing if we have a connection
-                if self.has_connection:
-                    data = self.do_clipboard_operation(get_data)
-                    if data != self.data:
-                        self.process_clipboard(data)
-
-                time.sleep(1)
-        except KeyboardInterrupt:
-            self.quit()
+        return self.do_clipboard_operation(get_data)
 
     def update_clipboard(self, text):
         """Updates the system clipboard with the specified text"""
@@ -61,5 +53,5 @@ class Clip2ZeusWin32(Clip2ZeusApp):
         self.do_clipboard_operation(set_data, text=text)
 
 if __name__ == '__main__':
-    Clip2ZeusWin32()
+    Clip2ZeusWin32().start()
 
